@@ -1,11 +1,11 @@
-#include <sstream>
-
 #include "pytgutils.h"
 #include "exception.h"
 #include "server/device_class.h"
 #include "server/attr.h"
 #include "server/command.h"
 
+#include <sstream>
+
 using namespace boost::python;
 
 #define __AUX_DECL_CALL_DEVCLASS_METHOD \
@@ -44,21 +44,6 @@ void CppDeviceClass::create_command(const std::string &cmd_name,
         cmd_ptr->set_allowed(is_allowed);
     }
 
-    if (param_type == Tango::DEV_VOID)
-    {
-        if (result_type == Tango::DEV_VOID)
-            cmd_ptr->set_cmd_type(VOID_VOID);
-        else
-            cmd_ptr->set_cmd_type(VOID_OUT);
-    }
-    else
-    {
-        if (result_type == Tango::DEV_VOID)
-            cmd_ptr->set_cmd_type(IN_VOID);
-        else
-            cmd_ptr->set_cmd_type(IN_OUT);
-    }
-
     if (polling_period > 0)
         cmd_ptr->set_polling_period(polling_period);
     if (default_command)
